Learn R Programming

cbanalysis (version 0.2.0)

nvdescstat: Numerical Variable Descriptive Statistics returns a data frame containing descriptive statistics for numerical variable.

Description

Returns a data frame containing following descriptive statistics for numerical variables in a data frame. Min Value -Minimum value of the variable. Max Value -Maximum value of the variable. Mean -Mean of the variable. Median -Median of the variable. Variance -Variance of the variable. Standard Deviation -Standard Deviation of the variable. Lower Outlier Cutoff -This helps to detect Lower outliers. Upper Outlier Cutoff -This helps to detect Upper outliers.

Usage

nvdescstat(df)

Arguments

df

- Input Data frame.

Value

Returns a data frame containing descriptive statistics for numerical variable.

Examples

Run this code
# NOT RUN {
numv1<-c(8000,200,323)
numv2<-c(400,533,633)
numv3<-c(100,534,734)
numv4<-c(1,25,34)
chrv6<-c("a","b","c")
numv5<-c(50,10000,34000)
chrv7<-as.factor(c("male","female","unknown"))
numv6<-c(NA,300,340)
df<-data.frame(numv1,numv2,chrv6,numv3,numv4,numv5,chrv7,numv6)
nvdescstatdf<-nvdescstat(df)
# }

Run the code above in your browser using DataLab